summaryrefslogtreecommitdiffstats
path: root/nicintel.c
diff options
context:
space:
mode:
Diffstat (limited to 'nicintel.c')
-rw-r--r--nicintel.c7
1 files changed, 3 insertions, 4 deletions
diff --git a/nicintel.c b/nicintel.c
index 813049c..1c6d409 100644
--- a/nicintel.c
+++ b/nicintel.c
@@ -64,7 +64,6 @@ static int nicintel_shutdown(void *data)
physunmap(nicintel_control_bar, NICINTEL_CONTROL_MEMMAP_SIZE);
physunmap(nicintel_bar, NICINTEL_MEMMAP_SIZE);
pci_cleanup(pacc);
- release_io_perms();
return 0;
}
@@ -73,9 +72,10 @@ int nicintel_init(void)
uintptr_t addr;
/* Needed only for PCI accesses on some platforms.
* FIXME: Refactor that into get_mem_perms/get_io_perms/get_pci_perms?
*/
- get_io_perms();
+ if (rget_io_perms())
+ return 1;
/* No need to check for errors, pcidev_init() will not return in case
* of errors.
@@ -118,7 +118,6 @@ error_out_unmap:
physunmap(nicintel_bar, NICINTEL_MEMMAP_SIZE);
error_out:
pci_cleanup(pacc);
- release_io_perms();
return 1;
}
OpenPOWER on IntegriCloud
@@ -73,9 +72,10 @@ int nicintel_init(void)
uintptr_t addr;
/* Needed only for PCI accesses on some platforms.
- * FIXME: Refactor that into get_mem_perms/get_io_perms/get_pci_perms?
+ * FIXME: Refactor that into get_mem_perms/rget_io_perms/get_pci_perms?
*/